@@ -61,6 +61,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.mail.MailField;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.dataobjects.MailMessage;
+import com.openexchange.mail.mime.MimeDefaultSession;
 import com.openexchange.mail.mime.utils.MimeMessageUtility;
 import com.openexchange.mail.service.MailService;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
@@ -111,7 +112,7 @@ public class SpamExpertsSpamHandler extends SpamHandler {
         String imapUser = config.requireProperty(session, "com.openexchange.custom.spamexperts.imapuser");
         String imapPassword = config.requireProperty(session, "com.openexchange.custom.spamexperts.imappassword");
 
-        final Properties props = new Properties();
+        final Properties props = MimeDefaultSession.getDefaultMailProperties();
         if ("imaps".equals(imapUrl.getScheme())) {
             props.put("mail.imap.socketFactory.class", socketFactoryClass);
         } else {
@@ -159,9 +160,6 @@ public class SpamExpertsSpamHandler extends SpamHandler {
         }
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.spamhandler.SpamHandler#handleHam(int, java.lang.String, java.lang.String[], boolean, com.openexchange.session.Session)
-     */
     @Override
     public void handleHam(int accountId, String spamFullName, String[] mailIDs, boolean move, Session session) throws OXException {
         LOG.debug("handleHam");
