@@ -24,7 +24,6 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.google.common.io.BaseEncoding;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Strings;
@@ -34,6 +33,7 @@ import com.openexchange.spamhandler.spamexperts.exceptions.SpamExpertsExceptionC
 import com.openexchange.spamhandler.spamexperts.management.SpamExpertsConfig;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.user.User;
 
 /*
  *
@@ -302,7 +302,7 @@ public final class SpamExpertsServletRequest {
             URIBuilder builder = new URIBuilder();
             builder.setScheme(baseUri.getScheme()).setHost(baseUri.getHost()).setPort(baseUri.getPort()).setPath(null == optPath ? baseUri.getPath() : optPath).setQuery(null == queryString ? null : URLEncodedUtils.format(queryString, "UTF-8"));
             return builder.build();
-        } catch (final URISyntaxException x) {
+        } catch (URISyntaxException x) {
             throw new IllegalArgumentException("Failed to build URI", x);
         }
     }
